pub fn azure_config_from_connection_string(
conn_str: &str,
storage: AzureStorageService,
) -> Result<AzureStorageConfig>Expand description
Parses an Azure connection string into a configuration object.
The connection string doesn’t have to specify all required parameters because the user is still allowed to set them later directly on the object.
The function takes an AzureStorageService parameter because it determines the fields used to parse the endpoint.